@@ -20,6 +20,7 @@ namespace Tomboy
 		public const string CUSTOM_FONT_FACE = "/apps/tomboy/custom_font_face";
 		public const string MENU_NOTE_COUNT = "/apps/tomboy/menu_note_count";
 		public const string MENU_PINNED_NOTES = "/apps/tomboy/menu_pinned_notes";
+		public const string MENU_ITEM_MAX_LENGTH = "/apps/tomboy/tray_menu_item_max_length";
 
 		public const string KEYBINDING_SHOW_NOTE_MENU = "/apps/tomboy/global_keybindings/show_note_menu";
 		public const string KEYBINDING_OPEN_START_HERE = "/apps/tomboy/global_keybindings/open_start_here";
@@ -40,23 +41,20 @@ namespace Tomboy
 
 		public const string INSERT_TIMESTAMP_FORMAT = "/apps/tomboy/insert_timestamp/format";
 		
-		// TODO: Convert these into properly localized settings in 0.11.x after freeze is lifted
 		public const string SEARCH_WINDOW_X_POS = "/apps/tomboy/search_window_x_pos";
 		public const string SEARCH_WINDOW_Y_POS = "/apps/tomboy/search_window_y_pos";
 		public const string SEARCH_WINDOW_WIDTH = "/apps/tomboy/search_window_width";
 		public const string SEARCH_WINDOW_HEIGHT = "/apps/tomboy/search_window_height";
+		public const string SEARCH_WINDOW_SPLITTER_POS = "/apps/tomboy/search_window_splitter_pos";
 
-		static GConf.Client client;
-		static GConf.NotifyEventHandler changed_handler;
+		static IPreferencesClient client;
 
-		public static GConf.Client Client
+		public static IPreferencesClient Client
 		{
 			get {
 				if (client == null) {
-					client = new GConf.Client ();
-
-					changed_handler = new GConf.NotifyEventHandler (OnSettingChanged);
-					client.AddNotify ("/apps/tomboy", changed_handler);
+					client = Services.Preferences;
+					client.AddNotify ("/apps/tomboy", OnSettingChanged);
 				}
 				return client;
 			}
@@ -97,6 +95,9 @@ namespace Tomboy
 			case MENU_PINNED_NOTES:
 				return string.Empty;
 
+			case MENU_ITEM_MAX_LENGTH:
+				return 100;
+
 			case KEYBINDING_SHOW_NOTE_MENU:
 				return "<Alt>F12";
 
@@ -125,7 +126,6 @@ namespace Tomboy
 
 			case SYNC_CLIENT_ID:
 				return System.Guid.NewGuid ().ToString ();
-				break;
 
 			case SYNC_LOCAL_PATH:
 				return string.Empty;
@@ -144,7 +144,7 @@ namespace Tomboy
 		{
 			try {
 				return Client.Get (key);
-			} catch (GConf.NoSuchKeyException) {
+			} catch (NoSuchKeyException) {
 				object default_val = GetDefault (key);
 
 				if (default_val != null)
@@ -159,9 +159,9 @@ namespace Tomboy
 			Client.Set (key, value);
 		}
 
-		public static event GConf.NotifyEventHandler SettingChanged;
+		public static event NotifyEventHandler SettingChanged;
 
-		static void OnSettingChanged (object sender, GConf.NotifyEventArgs args)
+		static void OnSettingChanged (object sender, NotifyEventArgs args)
 		{
 			if (SettingChanged != null) {
 				SettingChanged (sender, args);
